@@ -1,4 +1,4 @@
-# $Id: RSS.pm 150 2009-05-07 00:47:58Z swistow $
+# $Id$
 
 package XML::Feed::Format::RSS;
 use strict;
@@ -6,6 +6,7 @@ use strict;
 use base qw( XML::Feed );
 use DateTime::Format::Mail;
 use DateTime::Format::W3CDTF;
+use XML::Atom::Util qw(iso2dt);
 
 our $PREFERRED_PARSER = "XML::RSS";
 
@@ -49,6 +50,7 @@ sub format { 'RSS ' . $_[0]->{rss}->{'version'} }
 sub title       { shift->{rss}->channel('title', @_) }
 sub link        { shift->{rss}->channel('link', @_) }
 sub description { shift->{rss}->channel('description', @_) }
+sub updated     { shift->modified(@_) }
 
 # This doesn't exist in RSS
 sub id          { }
@@ -215,6 +217,10 @@ sub summary {
             ($item->{content}{encoded} ||
              $item->{'http://www.w3.org/1999/xhtml'}{body})) {
             $txt = $item->{description};
+        ## Blogspot's 'short' RSS feeds do this in the Atom namespace
+        ## for no obviously good reason.
+        } elsif ($item->{'http://www.w3.org/2005/Atom'}{summary}) {
+            $txt = $item->{'http://www.w3.org/2005/Atom'}{summary};
         }
         XML::Feed::Content->wrap({ type => 'text/plain', body => $txt });
     }
@@ -295,8 +301,8 @@ sub issued {
                 my $parser = DateTime::Format::Mail->new;
                 $parser->loose;
                 $date = $parser->parse_datetime($ts);
-            } elsif ($ts = $item->{dc}{date}) {
-                $date = DateTime::Format::W3CDTF->parse_datetime($ts);
+            } elsif ($ts = $item->{dc}{date} or $ts = $item->{dcterms}{date}) {
+               $date = DateTime::Format::W3CDTF->parse_datetime($ts);
             }
         };
         return $date;
@@ -309,9 +315,9 @@ sub modified {
         $item->{dcterms}{modified} =
             DateTime::Format::W3CDTF->format_datetime($_[0]);
     } else {
-        if (my $ts = $item->{dcterms}{modified}) {
-            return eval { DateTime::Format::W3CDTF->parse_datetime($ts) };
-        }
+        if (my $ts = $item->{dcterms}{modified} || $item->{'http://www.w3.org/2005/Atom'}{updated}) {
+            return eval { DateTime::Format::W3CDTF->parse_datetime($ts) } || eval { XML::Atom::Util::iso2dt($ts) };
+        } 
     }
 }
 
